==> haskell-hastache-0.6.1-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hastache.sh <==
#!/bin/sh
export PATH='/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hastache
version: 0.6.1
id: hastache-0.6.1-AnZxeJc4QP65v3cR8TBiTp
key: hastache-0.6.1-AnZxeJc4QP65v3cR8TBiTp
license: BSD3
copyright: Sergey S Lymar (c) 2011-2014
maintainer: Daniil Frumin <dan at covariant.me>
stability: experimental
homepage: http://github.com/lymar/hastache
synopsis: Haskell implementation of Mustache templates
description:
    Haskell implementation of Mustache templates (<http://mustache.github.com/>).
    .
    See homepage for examples of usage: <http://github.com/lymar/hastache>
category: Text
author: Sergey S Lymar <sergey.lymar@gmail.com>
exposed: True
exposed-modules:
    Text.Hastache Text.Hastache.Context
abi: ca47d60ef00dd84c43e289b7213a0e00
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hastache-0.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/hastache-0.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/hastache-0.6.1
hs-libraries: HShastache-0.6.1-AnZxeJc4QP65v3cR8TBiTp
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 containers-0.5.7.1 directory-1.2.6.2
    filepath-1.4.1.0 ieee754-0.7.9-GGOMObQlFhs75IwEfmeIx2
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM syb-0.6-C65vWCsht6A8uLstpQIXyj
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hastache/html/hastache.haddock
haddock-html: /usr/share/doc/haskell-hastache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hastache-0.6.1-7-i686.pkg.tar.xz: usr/share/haskell/register/haskell-hastache.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hastache
version: 0.6.1
id: hastache-0.6.1-GCCuVHv6gMaBi8dHsSmSEp
key: hastache-0.6.1-GCCuVHv6gMaBi8dHsSmSEp
license: BSD3
copyright: Sergey S Lymar (c) 2011-2014
maintainer: Daniil Frumin <dan at covariant.me>
stability: experimental
homepage: http://github.com/lymar/hastache
synopsis: Haskell implementation of Mustache templates
description:
    Haskell implementation of Mustache templates (<http://mustache.github.com/>).
    .
    See homepage for examples of usage: <http://github.com/lymar/hastache>
category: Text
author: Sergey S Lymar <sergey.lymar@gmail.com>
exposed: True
exposed-modules:
    Text.Hastache Text.Hastache.Context
abi: 2e9b4796e70f50654bae95ab5538b526
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hastache-0.6.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/hastache-0.6.1
data-dir: /usr/share/i386-linux-ghc-8.0.1/hastache-0.6.1
hs-libraries: HShastache-0.6.1-GCCuVHv6gMaBi8dHsSmSEp
depends:
    base-4.9.0.0 blaze-builder-0.4.0.2-2VmGHau0mFrAjwd4n28WWF
    bytestring-0.10.8.1 containers-0.5.7.1 directory-1.2.6.2
    filepath-1.4.1.0 ieee754-0.8.0-JtjfCwOgwtBGK0IQYGifQi
    mtl-2.2.1-6qsR1PHUy5lL47Hpoa4jCM syb-0.6-C65vWCsht6A8uLstpQIXyj
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ transformers-0.5.2.0
haddock-interfaces: /usr/share/doc/haskell-hastache/html/hastache.haddock
haddock-html: /usr/share/doc/haskell-hastache/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
